// SPDX-FileCopyrightText: Copyright 2024 shadPS4 Emulator Project
// SPDX-License-Identifier: GPL-2.0-or-later

#pragma once

#include "common/types.h"

namespace Core::Loader {
class SymbolsResolver;
}

namespace Libraries::NpCommon {

constexpr int ORBIS_NP_ONLINEID_MAX_LENGTH = 16;

struct OrbisNpOnlineId {
    char data[ORBIS_NP_ONLINEID_MAX_LENGTH];
    s8 term;
    s8 dummy[3];
};

struct OrbisNpId {
    OrbisNpOnlineId handle;
    u8 opt[8];
    u8 reserved[8];
};

int PS4_SYSV_ABI sceNpCmpNpId(OrbisNpId* np_id1, OrbisNpId* np_id2);
int PS4_SYSV_ABI sceNpCmpNpIdInOrder(OrbisNpId* np_id1, OrbisNpId* np_id2, u32* out_result);
int PS4_SYSV_ABI sceNpCmpOnlineId(OrbisNpOnlineId* online_id1, OrbisNpOnlineId* online_id2);
int PS4_SYSV_ABI _sceNpAllocatorExConvertAllocator();
int PS4_SYSV_ABI _sceNpAllocatorExFree();
int PS4_SYSV_ABI _sceNpAllocatorExMalloc();
int PS4_SYSV_ABI _sceNpAllocatorExRealloc();
int PS4_SYSV_ABI _sceNpAllocatorExStrdup();
int PS4_SYSV_ABI _sceNpAllocatorExStrndup();
int PS4_SYSV_ABI _sceNpAllocatorFree();
int PS4_SYSV_ABI _sceNpAllocatorMalloc();
int PS4_SYSV_ABI _sceNpAllocatorRealloc();
int PS4_SYSV_ABI _sceNpAllocatorStrdup();
int PS4_SYSV_ABI _sceNpAllocatorStrndup();
int PS4_SYSV_ABI _sceNpFree();
int PS4_SYSV_ABI _sceNpHeapFree();
int PS4_SYSV_ABI _sceNpHeapMalloc();
int PS4_SYSV_ABI _sceNpHeapRealloc();
int PS4_SYSV_ABI _sceNpHeapStrdup();
int PS4_SYSV_ABI _sceNpHeapStrndup();
int PS4_SYSV_ABI _sceNpMalloc();
int PS4_SYSV_ABI _sceNpRealloc();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable10IsCanceledEv();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable10LockCancelEPKciS3_();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable11CheckCancelEPKciS3_();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable12UnlockCancelEPKciS3_();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable13SetCancelableEb();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable14SetupSubCancelEPS1_PKciS4_();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable16CleanupSubCancelEPS1_();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable4InitEv();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable6CancelEij();
int PS4_SYSV_ABI _ZN3sce2np10Cancelable7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np10CancelableC2Ev();
int PS4_SYSV_ABI _ZN3sce2np10CancelableD0Ev();
int PS4_SYSV_ABI _ZN3sce2np10CancelableD1Ev();
int PS4_SYSV_ABI _ZN3sce2np10CancelableD2Ev();
int PS4_SYSV_ABI _ZN3sce2np10CancelLock3EndEPKciS3_();
int PS4_SYSV_ABI _ZN3sce2np10CancelLock5BeginEPNS0_6HandleEPKciS5_();
int PS4_SYSV_ABI _ZN3sce2np10CancelLockC1Ev();
int PS4_SYSV_ABI _ZN3sce2np10CancelLockC2Ev();
int PS4_SYSV_ABI _ZN3sce2np10CancelLockD1Ev();
int PS4_SYSV_ABI _ZN3sce2np10CancelLockD2Ev();
int PS4_SYSV_ABI _ZN3sce2np10EventQueue10ClearAbortEt();
int PS4_SYSV_ABI _ZN3sce2np10EventQueue10TryDequeueEPvm();
int PS4_SYSV_ABI _ZN3sce2np10EventQueue4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np10EventQueue4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np10EventQueue4InitEPKcmm();
int PS4_SYSV_ABI _ZN3sce2np10EventQueue5AbortEt();
int PS4_SYSV_ABI _ZN3sce2np10EventQueue7DequeueEPvmj();
int PS4_SYSV_ABI _ZN3sce2np10EventQueue7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np10EventQueue7EnqueueEPKvmj();
int PS4_SYSV_ABI _ZN3sce2np10EventQueueC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np10EventQueueD0Ev();
int PS4_SYSV_ABI _ZN3sce2np10EventQueueD1Ev();
int PS4_SYSV_ABI _ZN3sce2np10EventQueueD2Ev();
int PS4_SYSV_ABI _ZN3sce2np10JsonNumber5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np10JsonNumber6SetNumEi();
int PS4_SYSV_ABI _ZN3sce2np10JsonNumber6SetNumEj();
int PS4_SYSV_ABI _ZN3sce2np10JsonNumber6SetNumEl();
int PS4_SYSV_ABI _ZN3sce2np10JsonNumber6SetNumEm();
int PS4_SYSV_ABI _ZN3sce2np10JsonNumber6SetNumEPKc();
int PS4_SYSV_ABI _ZN3sce2np10JsonObject16DeleteFieldValueEPKc();
int PS4_SYSV_ABI _ZN3sce2np10JsonObject5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np10JsonParser4InitEPK7JsonDefPNS1_12EventHandlerE();
int PS4_SYSV_ABI _ZN3sce2np10JsonParser5ParseEPKcm();
int PS4_SYSV_ABI _ZN3sce2np10JsonParserC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np10JsonParserD0Ev();
int PS4_SYSV_ABI _ZN3sce2np10JsonParserD1Ev();
int PS4_SYSV_ABI _ZN3sce2np10JsonParserD2Ev();
int PS4_SYSV_ABI _ZN3sce2np10JsonString5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np10JsonString6SetStrEPKc();
int PS4_SYSV_ABI _ZN3sce2np10MemoryFile4ReadEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np10MemoryFile4SyncEv();
int PS4_SYSV_ABI _ZN3sce2np10MemoryFile5CloseEv();
int PS4_SYSV_ABI _ZN3sce2np10MemoryFile5WriteEPNS0_6HandleEPKvmPm();
int PS4_SYSV_ABI _ZN3sce2np10MemoryFile8TruncateEl();
int PS4_SYSV_ABI _ZN3sce2np10MemoryFileC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np10MemoryFileD0Ev();
int PS4_SYSV_ABI _ZN3sce2np10MemoryFileD1Ev();
int PS4_SYSV_ABI _ZN3sce2np10MemoryFileD2Ev();
int PS4_SYSV_ABI
_ZN3sce2np12HttpTemplate19SetAuthInfoCallbackEPFii15SceHttpAuthTypePKcPcS5_iPPhPmPiPvESA_();
int PS4_SYSV_ABI _ZN3sce2np12HttpTemplate4InitEiPKcib();
int PS4_SYSV_ABI _ZN3sce2np12HttpTemplate7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np12HttpTemplateC1Ev();
int PS4_SYSV_ABI _ZN3sce2np12HttpTemplateC2Ev();
int PS4_SYSV_ABI _ZN3sce2np12HttpTemplateD0Ev();
int PS4_SYSV_ABI _ZN3sce2np12HttpTemplateD1Ev();
int PS4_SYSV_ABI _ZN3sce2np12HttpTemplateD2Ev();
int PS4_SYSV_ABI _ZN3sce2np12StreamBufferixEi();
int PS4_SYSV_ABI _ZN3sce2np12StreamReader4ReadEPNS0_6HandleEPNS0_9StreamCtxEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np12StreamReader7ReadAllEPNS0_6HandleEPNS0_9StreamCtxEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np12StreamReader7ReadAllEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np12StreamReader8ReadDataEPNS0_6HandleEPNS0_9StreamCtxEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np12StreamReader8ReadDataEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np12StreamReader8SkipDataEPNS0_6HandleElPl();
int PS4_SYSV_ABI _ZN3sce2np12StreamReader8SkipDataEPNS0_6HandleEPNS0_9StreamCtxElPl();
int PS4_SYSV_ABI _ZN3sce2np12StreamWriter15WriteFilledDataEPNS0_6HandleEcl();
int PS4_SYSV_ABI _ZN3sce2np12StreamWriter15WriteFilledDataEPNS0_6HandleEPNS0_9StreamCtxEcl();
int PS4_SYSV_ABI _ZN3sce2np12StreamWriter5WriteEPNS0_6HandleEPNS0_9StreamCtxEPKvmPm();
int PS4_SYSV_ABI _ZN3sce2np12StreamWriter9WriteDataEPNS0_6HandleEPKvmPm();
int PS4_SYSV_ABI _ZN3sce2np12StreamWriter9WriteDataEPNS0_6HandleEPNS0_9StreamCtxEPKvmPm();
int PS4_SYSV_ABI _ZN3sce2np12WorkerThread10ThreadMainEv();
int PS4_SYSV_ABI _ZN3sce2np12WorkerThreadC1EPNS0_9WorkQueueE();
int PS4_SYSV_ABI _ZN3sce2np12WorkerThreadC2EPNS0_9WorkQueueE();
int PS4_SYSV_ABI _ZN3sce2np12WorkerThreadD0Ev();
int PS4_SYSV_ABI _ZN3sce2np12WorkerThreadD1Ev();
int PS4_SYSV_ABI _ZN3sce2np12WorkerThreadD2Ev();
int PS4_SYSV_ABI _ZN3sce2np13JsonDocParser5ParseEPKcm();
int PS4_SYSV_ABI _ZN3sce2np13JsonDocParser9GetResultEPPNS0_10JsonObjectE();
int PS4_SYSV_ABI _ZN3sce2np13JsonDocParser9GetResultEPPNS0_9JsonValueE();
int PS4_SYSV_ABI _ZN3sce2np13JsonDocParserC2EP16SceNpAllocatorExPK7JsonDef();
int PS4_SYSV_ABI _ZN3sce2np13JsonDocParserD0Ev();
int PS4_SYSV_ABI _ZN3sce2np13JsonDocParserD1Ev();
int PS4_SYSV_ABI _ZN3sce2np13JsonDocParserD2Ev();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecret5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretC1EPKvm();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretC1ERK16SceNpTitleSecret();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretC1ERKS1_();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretC1Ev();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretC2EPKvm();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretC2ERK16SceNpTitleSecret();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretC2ERKS1_();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretC2Ev();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretD0Ev();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretD1Ev();
int PS4_SYSV_ABI _ZN3sce2np13NpTitleSecretD2Ev();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemory4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemory4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemory4InitEm();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemory6ExpandEm();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemory6IsInitEv();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemory7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemoryC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemoryD0Ev();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemoryD1Ev();
int PS4_SYSV_ABI _ZN3sce2np13RingBufMemoryD2Ev();
int PS4_SYSV_ABI _ZN3sce2np14CalloutContext4InitEPKcimm();
int PS4_SYSV_ABI _ZN3sce2np14CalloutContext4InitEPKNS1_5ParamE();
int PS4_SYSV_ABI _ZN3sce2np14CalloutContext7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np14CalloutContextC1Ev();
int PS4_SYSV_ABI _ZN3sce2np14CalloutContextC2Ev();
int PS4_SYSV_ABI _ZN3sce2np14CalloutContextD0Ev();
int PS4_SYSV_ABI _ZN3sce2np14CalloutContextD1Ev();
int PS4_SYSV_ABI _ZN3sce2np14CalloutContextD2Ev();
int PS4_SYSV_ABI _ZN3sce2np14JsonDocBuilder12BuildBufSizeEv();
int PS4_SYSV_ABI _ZN3sce2np14JsonDocBuilder16EscapeJsonStringEPKcPcmPm();
int PS4_SYSV_ABI _ZN3sce2np14JsonDocBuilder23EscapeJsonStringBufSizeEPKc();
int PS4_SYSV_ABI _ZN3sce2np14JsonDocBuilder5BuildEPcmPm();
int PS4_SYSV_ABI _ZN3sce2np14JsonDocBuilderC1ERKNS0_9JsonValueE();
int PS4_SYSV_ABI _ZN3sce2np14JsonDocBuilderC2ERKNS0_9JsonValueE();
int PS4_SYSV_ABI _ZN3sce2np14JsonDocBuilderD0Ev();
int PS4_SYSV_ABI _ZN3sce2np14JsonDocBuilderD1Ev();
int PS4_SYSV_ABI _ZN3sce2np14JsonDocBuilderD2Ev();
int PS4_SYSV_ABI _ZN3sce2np15CancelableScope3EndEiPKciS3_();
int PS4_SYSV_ABI _ZN3sce2np15CancelableScope5BeginEPNS0_6HandleEPKciS5_();
int PS4_SYSV_ABI _ZN3sce2np15CancelableScopeC2Ev();
int PS4_SYSV_ABI _ZN3sce2np15CancelableScopeD0Ev();
int PS4_SYSV_ABI _ZN3sce2np15CancelableScopeD1Ev();
int PS4_SYSV_ABI _ZN3sce2np15CancelableScopeD2Ev();
int PS4_SYSV_ABI _ZN3sce2np16StreamReadBufferC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np16StreamReadBufferD1Ev();
int PS4_SYSV_ABI _ZN3sce2np16StreamReadBufferD2Ev();
int PS4_SYSV_ABI _ZN3sce2np18HttpConnectionPool13InvalidateAllEv();
int PS4_SYSV_ABI _ZN3sce2np18HttpConnectionPool4InitEi();
int PS4_SYSV_ABI _ZN3sce2np18HttpConnectionPool7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np18HttpConnectionPoolC1EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np18HttpConnectionPoolC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np18HttpConnectionPoolD0Ev();
int PS4_SYSV_ABI _ZN3sce2np18HttpConnectionPoolD1Ev();
int PS4_SYSV_ABI _ZN3sce2np18HttpConnectionPoolD2Ev();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamReader4ReadEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamReaderC1EPKvm();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamReaderC2EPKvm();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamReaderD0Ev();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamReaderD1Ev();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamReaderD2Ev();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamWriter5WriteEPNS0_6HandleEPKvmPm();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamWriterC1EPvm();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamWriterC2EPvm();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamWriterD0Ev();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamWriterD1Ev();
int PS4_SYSV_ABI _ZN3sce2np18MemoryStreamWriterD2Ev();
int PS4_SYSV_ABI _ZN3sce2np20BufferedStreamReader4ReadEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np20BufferedStreamReader5CloseEv();
int PS4_SYSV_ABI _ZN3sce2np20BufferedStreamReaderC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np20BufferedStreamReaderD0Ev();
int PS4_SYSV_ABI _ZN3sce2np20BufferedStreamReaderD1Ev();
int PS4_SYSV_ABI _ZN3sce2np20BufferedStreamReaderD2Ev();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClient10DisconnectEv();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClient11IsConnectedEv();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClient16invokeSyncMethodEjPKvmPvPmm();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClient4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClient4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClient4InitEPKNS2_6ConfigE();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClient7ConnectEPKvm();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClient7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClientC1Ev();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClientC2Ev();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClientD0Ev();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClientD1Ev();
int PS4_SYSV_ABI _ZN3sce2np3ipc10IpmiClientD2Ev();
int PS4_SYSV_ABI
_ZN3sce2np3ipc13ServiceClientC1EPNS1_17ServiceIpmiClientEPKNS1_17ServiceClientInfoE();
int PS4_SYSV_ABI
_ZN3sce2np3ipc13ServiceClientC2EPNS1_17ServiceIpmiClientEPKNS1_17ServiceClientInfoE();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient10DisconnectEv();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient10EndRequestEii();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient11findServiceEi();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient11InitServiceEi();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient11TermServiceEi();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient11WaitRequestEiij();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient12AbortRequestEii();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient12BeginRequestEii();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient13CreateRequestEPiiPKvm();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient13DeleteRequestEii();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient13PollEventFlagEijmjPm();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient13WaitEventFlagEijmjPmj();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient14PollEventQueueEiPvm();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient15CancelEventFlagEijm();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient15RegisterServiceEPKNS1_17ServiceClientInfoE();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient16RegisterServicesEPKNS1_17ServiceClientInfoE();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient17invokeInitServiceEi();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient17invokeTermServiceEi();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient17UnregisterServiceEi();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient18EndRequestForAsyncEii();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient19WaitRequestForAsyncEiij();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient20AbortRequestForAsyncEii();
int PS4_SYSV_ABI
_ZN3sce2np3ipc17ServiceIpmiClient20BeginRequestForAsyncEiiPN4IPMI6Client12EventNotifeeE();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient21CreateRequestForAsyncEPiiPKvm();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient21DeleteRequestForAsyncEii();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient4InitEPNS2_6ConfigE();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient7ConnectEPKvm();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClient7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClientC1Ev();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClientC2Ev();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClientD0Ev();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClientD1Ev();
int PS4_SYSV_ABI _ZN3sce2np3ipc17ServiceIpmiClientD2Ev();
int PS4_SYSV_ABI _ZN3sce2np4Cond4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np4Cond4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np4Cond4InitEPKcPNS0_5MutexE();
int PS4_SYSV_ABI _ZN3sce2np4Cond4WaitEj();
int PS4_SYSV_ABI _ZN3sce2np4Cond6SignalEv();
int PS4_SYSV_ABI _ZN3sce2np4Cond7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np4Cond9SignalAllEv();
int PS4_SYSV_ABI _ZN3sce2np4CondC1Ev();
int PS4_SYSV_ABI _ZN3sce2np4CondC2Ev();
int PS4_SYSV_ABI _ZN3sce2np4CondD0Ev();
int PS4_SYSV_ABI _ZN3sce2np4CondD1Ev();
int PS4_SYSV_ABI _ZN3sce2np4CondD2Ev();
int PS4_SYSV_ABI _ZN3sce2np4Path11BuildAppendEPcmcPKcm();
int PS4_SYSV_ABI _ZN3sce2np4Path12AddDelimiterEPcmc();
int PS4_SYSV_ABI _ZN3sce2np4Path5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np4Path6SetStrEPKcm();
int PS4_SYSV_ABI _ZN3sce2np4PathD0Ev();
int PS4_SYSV_ABI _ZN3sce2np4PathD1Ev();
int PS4_SYSV_ABI _ZN3sce2np4PathD2Ev();
int PS4_SYSV_ABI _ZN3sce2np4Time10AddMinutesEl();
int PS4_SYSV_ABI _ZN3sce2np4Time10AddSecondsEl();
int PS4_SYSV_ABI _ZN3sce2np4Time12GetUserClockEPS1_();
int PS4_SYSV_ABI _ZN3sce2np4Time15AddMicroSecondsEl();
int PS4_SYSV_ABI _ZN3sce2np4Time15GetNetworkClockEPS1_();
int PS4_SYSV_ABI _ZN3sce2np4Time20GetDebugNetworkClockEPS1_();
int PS4_SYSV_ABI _ZN3sce2np4Time7AddDaysEl();
int PS4_SYSV_ABI _ZN3sce2np4Time8AddHoursEl();
int PS4_SYSV_ABI _ZN3sce2np4TimeplERK10SceRtcTick();
int PS4_SYSV_ABI _ZN3sce2np4TimeplERKS1_();
int PS4_SYSV_ABI _ZN3sce2np5Mutex4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np5Mutex4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np5Mutex4InitEPKcj();
int PS4_SYSV_ABI _ZN3sce2np5Mutex4LockEv();
int PS4_SYSV_ABI _ZN3sce2np5Mutex6UnlockEv();
int PS4_SYSV_ABI _ZN3sce2np5Mutex7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np5Mutex7TryLockEv();
int PS4_SYSV_ABI _ZN3sce2np5MutexC1Ev();
int PS4_SYSV_ABI _ZN3sce2np5MutexC2Ev();
int PS4_SYSV_ABI _ZN3sce2np5MutexD0Ev();
int PS4_SYSV_ABI _ZN3sce2np5MutexD1Ev();
int PS4_SYSV_ABI _ZN3sce2np5MutexD2Ev();
int PS4_SYSV_ABI _ZN3sce2np5NpEnv8GetNpEnvEPS1_();
int PS4_SYSV_ABI _ZN3sce2np6Handle10CancelImplEi();
int PS4_SYSV_ABI _ZN3sce2np6Handle4InitEv();
int PS4_SYSV_ABI _ZN3sce2np6Handle7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np6HandleC1Ev();
int PS4_SYSV_ABI _ZN3sce2np6HandleC2Ev();
int PS4_SYSV_ABI _ZN3sce2np6HandleD0Ev();
int PS4_SYSV_ABI _ZN3sce2np6HandleD1Ev();
int PS4_SYSV_ABI _ZN3sce2np6HandleD2Ev();
int PS4_SYSV_ABI _ZN3sce2np6ObjectdaEPv();
int PS4_SYSV_ABI _ZN3sce2np6ObjectdaEPvR14SceNpAllocator();
int PS4_SYSV_ABI _ZN3sce2np6ObjectdaEPvR16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np6ObjectdlEPv();
int PS4_SYSV_ABI _ZN3sce2np6ObjectdlEPvR14SceNpAllocator();
int PS4_SYSV_ABI _ZN3sce2np6ObjectdlEPvR16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np6ObjectnaEmR14SceNpAllocator();
int PS4_SYSV_ABI _ZN3sce2np6ObjectnaEmR16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np6ObjectnwEmR14SceNpAllocator();
int PS4_SYSV_ABI _ZN3sce2np6ObjectnwEmR16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np6Thread12DoThreadMainEv();
int PS4_SYSV_ABI _ZN3sce2np6Thread4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np6Thread4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np6Thread4InitEPKcimm();
int PS4_SYSV_ABI _ZN3sce2np6Thread4InitEPKNS1_5ParamE();
int PS4_SYSV_ABI _ZN3sce2np6Thread4JoinEPi();
int PS4_SYSV_ABI _ZN3sce2np6Thread5StartEv();
int PS4_SYSV_ABI _ZN3sce2np6Thread7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np6Thread9EntryFuncEPv();
int PS4_SYSV_ABI _ZN3sce2np6Thread9GetResultEv();
int PS4_SYSV_ABI _ZN3sce2np6Thread9IsRunningEv();
int PS4_SYSV_ABI _ZN3sce2np6ThreadC2Ev();
int PS4_SYSV_ABI _ZN3sce2np6ThreadD0Ev();
int PS4_SYSV_ABI _ZN3sce2np6ThreadD1Ev();
int PS4_SYSV_ABI _ZN3sce2np6ThreadD2Ev();
int PS4_SYSV_ABI _ZN3sce2np7Callout10IsTimedoutEv();
int PS4_SYSV_ABI _ZN3sce2np7Callout11CalloutFuncEPv();
int PS4_SYSV_ABI _ZN3sce2np7Callout4StopEv();
int PS4_SYSV_ABI _ZN3sce2np7Callout5StartEjPNS1_7HandlerE();
int PS4_SYSV_ABI _ZN3sce2np7Callout5StartEmPNS1_7HandlerE();
int PS4_SYSV_ABI _ZN3sce2np7Callout9IsStartedEv();
int PS4_SYSV_ABI _ZN3sce2np7CalloutC1EPNS0_14CalloutContextE();
int PS4_SYSV_ABI _ZN3sce2np7CalloutC2EPNS0_14CalloutContextE();
int PS4_SYSV_ABI _ZN3sce2np7CalloutD0Ev();
int PS4_SYSV_ABI _ZN3sce2np7CalloutD1Ev();
int PS4_SYSV_ABI _ZN3sce2np7CalloutD2Ev();
int PS4_SYSV_ABI _ZN3sce2np7HttpUri5BuildEPKS1_PcmPmj();
int PS4_SYSV_ABI _ZN3sce2np7HttpUri5ParseEPS1_PKc();
int PS4_SYSV_ABI _ZN3sce2np7HttpUriC1EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np7HttpUriC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np7HttpUriD0Ev();
int PS4_SYSV_ABI _ZN3sce2np7HttpUriD1Ev();
int PS4_SYSV_ABI _ZN3sce2np7HttpUriD2Ev();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf14CheckinForReadEm();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf15CheckinForWriteEm();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf15CheckoutForReadEPm();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf16CheckoutForWriteEPm();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf4InitEPvm();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf4PeekEmPvm();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf4ReadEPvm();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf5WriteEPKvm();
int PS4_SYSV_ABI _ZN3sce2np7RingBuf7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np7RingBufC1Ev();
int PS4_SYSV_ABI _ZN3sce2np7RingBufC2Ev();
int PS4_SYSV_ABI _ZN3sce2np7RingBufD0Ev();
int PS4_SYSV_ABI _ZN3sce2np7RingBufD1Ev();
int PS4_SYSV_ABI _ZN3sce2np7RingBufD2Ev();
int PS4_SYSV_ABI _ZN3sce2np8HttpFile4ReadEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np8HttpFile5CloseEv();
int PS4_SYSV_ABI _ZN3sce2np8HttpFileC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np8HttpFileD0Ev();
int PS4_SYSV_ABI _ZN3sce2np8HttpFileD1Ev();
int PS4_SYSV_ABI _ZN3sce2np8HttpFileD2Ev();
int PS4_SYSV_ABI _ZN3sce2np8JsonBool5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np8JsonBool7SetBoolEb();
int PS4_SYSV_ABI _ZN3sce2np8JsonFile5CloseEv();
int PS4_SYSV_ABI _ZN3sce2np8JsonFileD0Ev();
int PS4_SYSV_ABI _ZN3sce2np8JsonFileD1Ev();
int PS4_SYSV_ABI _ZN3sce2np8JsonFileD2Ev();
int PS4_SYSV_ABI _ZN3sce2np8JsonNull5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np8NpCommId5BuildERKS1_Pcm();
int PS4_SYSV_ABI _ZN3sce2np8NpCommId5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np8NpCommId5ParseEPS1_PKc();
int PS4_SYSV_ABI _ZN3sce2np8NpCommId5ParseEPS1_PKcm();
int PS4_SYSV_ABI _ZN3sce2np8NpCommIdC1ERK20SceNpCommunicationId();
int PS4_SYSV_ABI _ZN3sce2np8NpCommIdC1ERKS1_();
int PS4_SYSV_ABI _ZN3sce2np8NpCommIdC1Ev();
int PS4_SYSV_ABI _ZN3sce2np8NpCommIdC2ERK20SceNpCommunicationId();
int PS4_SYSV_ABI _ZN3sce2np8NpCommIdC2ERKS1_();
int PS4_SYSV_ABI _ZN3sce2np8NpCommIdC2Ev();
int PS4_SYSV_ABI _ZN3sce2np8NpCommIdD0Ev();
int PS4_SYSV_ABI _ZN3sce2np8NpCommIdD1Ev();
int PS4_SYSV_ABI _ZN3sce2np8NpCommIdD2Ev();
int PS4_SYSV_ABI _ZN3sce2np8Selector4InitEPKc();
int PS4_SYSV_ABI _ZN3sce2np8SelectorD0Ev();
int PS4_SYSV_ABI _ZN3sce2np8SelectorD1Ev();
int PS4_SYSV_ABI _ZN3sce2np8SelectorD2Ev();
int PS4_SYSV_ABI _ZN3sce2np8WorkItem10SetPendingEv();
int PS4_SYSV_ABI _ZN3sce2np8WorkItem10SetRunningEv();
int PS4_SYSV_ABI _ZN3sce2np8WorkItem11SetFinishedEi();
int PS4_SYSV_ABI _ZN3sce2np8WorkItem14FinishCallbackEv();
int PS4_SYSV_ABI _ZN3sce2np8WorkItem15RemoveFromQueueEv();
int PS4_SYSV_ABI _ZN3sce2np8WorkItem6CancelEi();
int PS4_SYSV_ABI _ZN3sce2np8WorkItem9BindQueueEPNS0_9WorkQueueEi();
int PS4_SYSV_ABI _ZN3sce2np8WorkItemC2EPKc();
int PS4_SYSV_ABI _ZN3sce2np8WorkItemD0Ev();
int PS4_SYSV_ABI _ZN3sce2np8WorkItemD1Ev();
int PS4_SYSV_ABI _ZN3sce2np8WorkItemD2Ev();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag3SetEm();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag4OpenEPKc();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag4PollEmjPm();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag4WaitEmjPmj();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag5ClearEm();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag6CancelEm();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag6CreateEPKcj();
int PS4_SYSV_ABI _ZN3sce2np9EventFlag7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np9EventFlagC1Ev();
int PS4_SYSV_ABI _ZN3sce2np9EventFlagC2Ev();
int PS4_SYSV_ABI _ZN3sce2np9EventFlagD0Ev();
int PS4_SYSV_ABI _ZN3sce2np9EventFlagD1Ev();
int PS4_SYSV_ABI _ZN3sce2np9EventFlagD2Ev();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans10SetTimeoutEPKNS1_12TimeoutParamE();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans11SendRequestEPNS0_6HandleEPKvm();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans12RecvResponseEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans12SkipResponseEPNS0_6HandleE();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans16AddRequestHeaderEPKcS3_();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans16SetRequestHeaderEPKcS3_();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans21GetResponseStatusCodeEPNS0_6HandleEPi();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans21SetRequestContentTypeEPKc();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans23SetRequestContentLengthEm();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans24GetResponseContentLengthEPNS0_6HandleEPbPm();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans4InitERKNS0_12HttpTemplateEPNS0_18HttpConnectionPoolEiPKcm();
int PS4_SYSV_ABI
_ZN3sce2np9HttpTrans4InitERKNS0_12HttpTemplateEPNS0_18HttpConnectionPoolEiPKcS8_tS8_m();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans4ReadEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans5WriteEPNS0_6HandleEPKvmPm();
int PS4_SYSV_ABI _ZN3sce2np9HttpTrans7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np9HttpTransC1EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np9HttpTransC2EP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZN3sce2np9HttpTransD0Ev();
int PS4_SYSV_ABI _ZN3sce2np9HttpTransD1Ev();
int PS4_SYSV_ABI _ZN3sce2np9HttpTransD2Ev();
int PS4_SYSV_ABI _ZN3sce2np9JsonArray12AddItemArrayEPPS1_();
int PS4_SYSV_ABI _ZN3sce2np9JsonArray5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np9JsonValue12GetItemValueEi();
int PS4_SYSV_ABI _ZN3sce2np9JsonValue13GetFieldValueEiPPKc();
int PS4_SYSV_ABI _ZN3sce2np9JsonValue13GetFieldValueEPKc();
int PS4_SYSV_ABI _ZN3sce2np9JsonValueD0Ev();
int PS4_SYSV_ABI _ZN3sce2np9JsonValueD1Ev();
int PS4_SYSV_ABI _ZN3sce2np9JsonValueD2Ev();
int PS4_SYSV_ABI _ZN3sce2np9LocalFile4ReadEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZN3sce2np9LocalFile4SeekEliPl();
int PS4_SYSV_ABI _ZN3sce2np9LocalFile4SyncEv();
int PS4_SYSV_ABI _ZN3sce2np9LocalFile5CloseEv();
int PS4_SYSV_ABI _ZN3sce2np9LocalFile5WriteEPNS0_6HandleEPKvmPm();
int PS4_SYSV_ABI _ZN3sce2np9LocalFile6RemoveEPKc();
int PS4_SYSV_ABI _ZN3sce2np9LocalFile8TruncateEl();
int PS4_SYSV_ABI _ZN3sce2np9LocalFileC1Ev();
int PS4_SYSV_ABI _ZN3sce2np9LocalFileC2Ev();
int PS4_SYSV_ABI _ZN3sce2np9LocalFileD0Ev();
int PS4_SYSV_ABI _ZN3sce2np9LocalFileD1Ev();
int PS4_SYSV_ABI _ZN3sce2np9LocalFileD2Ev();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleId5BuildERKS1_Pcm();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleId5ClearEv();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleId5ParseEPS1_PKc();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleId5ParseEPS1_PKcm();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleIdC1ERK12SceNpTitleId();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleIdC1ERKS1_();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleIdC1Ev();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleIdC2ERK12SceNpTitleId();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleIdC2ERKS1_();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleIdC2Ev();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleIdD0Ev();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleIdD1Ev();
int PS4_SYSV_ABI _ZN3sce2np9NpTitleIdD2Ev();
int PS4_SYSV_ABI _ZN3sce2np9RefObject6AddRefEv();
int PS4_SYSV_ABI _ZN3sce2np9RefObject7ReleaseEv();
int PS4_SYSV_ABI _ZN3sce2np9RefObjectC1Ev();
int PS4_SYSV_ABI _ZN3sce2np9RefObjectC2Ev();
int PS4_SYSV_ABI _ZN3sce2np9RefObjectD0Ev();
int PS4_SYSV_ABI _ZN3sce2np9RefObjectD1Ev();
int PS4_SYSV_ABI _ZN3sce2np9RefObjectD2Ev();
int PS4_SYSV_ABI _ZN3sce2np9Semaphore4OpenEPKc();
int PS4_SYSV_ABI _ZN3sce2np9Semaphore4WaitEj();
int PS4_SYSV_ABI _ZN3sce2np9Semaphore6CreateEiiPKc();
int PS4_SYSV_ABI _ZN3sce2np9Semaphore6SignalEv();
int PS4_SYSV_ABI _ZN3sce2np9Semaphore7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np9SemaphoreC1Ev();
int PS4_SYSV_ABI _ZN3sce2np9SemaphoreC2Ev();
int PS4_SYSV_ABI _ZN3sce2np9SemaphoreD0Ev();
int PS4_SYSV_ABI _ZN3sce2np9SemaphoreD1Ev();
int PS4_SYSV_ABI _ZN3sce2np9SemaphoreD2Ev();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue11GetItemByIdEi();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue15GetFinishedItemENS0_14WorkItemStatusE();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue16WorkItemFinishedEPNS0_8WorkItemEi();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue17ProcFinishedItemsENS0_14WorkItemStatusE();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue18RemoveFinishedItemEPNS0_8WorkItemE();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue18WaitForPendingItemEPPNS0_8WorkItemEPb();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue4ctorEv();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue4dtorEv();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue4InitEPKcimm();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue4InitEPKNS0_6Thread5ParamE();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue4StopEv();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue5StartEv();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue6CancelEii();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue6IsInitEv();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue7DestroyEv();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue7EnqueueEiPNS0_8WorkItemE();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue9CancelAllEi();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueue9IsRunningEv();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueueC1Ev();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueueC2Ev();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueueD0Ev();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueueD1Ev();
int PS4_SYSV_ABI _ZN3sce2np9WorkQueueD2Ev();
int PS4_SYSV_ABI _ZN3sce2npeqERK10SceRtcTickRKNS0_4TimeE();
int PS4_SYSV_ABI _ZN3sce2npeqERK12SceNpTitleIdRKNS0_9NpTitleIdE();
int PS4_SYSV_ABI _ZN3sce2npeqERK16SceNpTitleSecretRKNS0_13NpTitleSecretE();
int PS4_SYSV_ABI _ZN3sce2npeqERK20SceNpCommunicationIdRKNS0_8NpCommIdE();
int PS4_SYSV_ABI _ZN3sce2npeqERKNS0_13NpTitleSecretERK16SceNpTitleSecret();
int PS4_SYSV_ABI _ZN3sce2npeqERKNS0_13NpTitleSecretES3_();
int PS4_SYSV_ABI _ZN3sce2npeqERKNS0_4TimeERK10SceRtcTick();
int PS4_SYSV_ABI _ZN3sce2npeqERKNS0_4TimeES3_();
int PS4_SYSV_ABI _ZN3sce2npeqERKNS0_8NpCommIdERK20SceNpCommunicationId();
int PS4_SYSV_ABI _ZN3sce2npeqERKNS0_8NpCommIdES3_();
int PS4_SYSV_ABI _ZN3sce2npeqERKNS0_9NpTitleIdERK12SceNpTitleId();
int PS4_SYSV_ABI _ZN3sce2npeqERKNS0_9NpTitleIdES3_();
int PS4_SYSV_ABI _ZN3sce2npgeERK10SceRtcTickRKNS0_4TimeE();
int PS4_SYSV_ABI _ZN3sce2npgeERKNS0_4TimeERK10SceRtcTick();
int PS4_SYSV_ABI _ZN3sce2npgeERKNS0_4TimeES3_();
int PS4_SYSV_ABI _ZN3sce2npgtERK10SceRtcTickRKNS0_4TimeE();
int PS4_SYSV_ABI _ZN3sce2npgtERKNS0_4TimeERK10SceRtcTick();
int PS4_SYSV_ABI _ZN3sce2npgtERKNS0_4TimeES3_();
int PS4_SYSV_ABI _ZN3sce2npleERK10SceRtcTickRKNS0_4TimeE();
int PS4_SYSV_ABI _ZN3sce2npleERKNS0_4TimeERK10SceRtcTick();
int PS4_SYSV_ABI _ZN3sce2npleERKNS0_4TimeES3_();
int PS4_SYSV_ABI _ZN3sce2npltERK10SceRtcTickRKNS0_4TimeE();
int PS4_SYSV_ABI _ZN3sce2npltERKNS0_4TimeERK10SceRtcTick();
int PS4_SYSV_ABI _ZN3sce2npltERKNS0_4TimeES3_();
int PS4_SYSV_ABI _ZN3sce2npneERK10SceRtcTickRKNS0_4TimeE();
int PS4_SYSV_ABI _ZN3sce2npneERK12SceNpTitleIdRKNS0_9NpTitleIdE();
int PS4_SYSV_ABI _ZN3sce2npneERK16SceNpTitleSecretRKNS0_13NpTitleSecretE();
int PS4_SYSV_ABI _ZN3sce2npneERK20SceNpCommunicationIdRKNS0_8NpCommIdE();
int PS4_SYSV_ABI _ZN3sce2npneERKNS0_13NpTitleSecretERK16SceNpTitleSecret();
int PS4_SYSV_ABI _ZN3sce2npneERKNS0_13NpTitleSecretES3_();
int PS4_SYSV_ABI _ZN3sce2npneERKNS0_4TimeERK10SceRtcTick();
int PS4_SYSV_ABI _ZN3sce2npneERKNS0_4TimeES3_();
int PS4_SYSV_ABI _ZN3sce2npneERKNS0_8NpCommIdERK20SceNpCommunicationId();
int PS4_SYSV_ABI _ZN3sce2npneERKNS0_8NpCommIdES3_();
int PS4_SYSV_ABI _ZN3sce2npneERKNS0_9NpTitleIdERK12SceNpTitleId();
int PS4_SYSV_ABI _ZN3sce2npneERKNS0_9NpTitleIdES3_();
int PS4_SYSV_ABI _ZNK3sce2np10Cancelable6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np10EventQueue6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np10EventQueue7IsEmptyEv();
int PS4_SYSV_ABI _ZNK3sce2np10JsonNumber5CloneEP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZNK3sce2np10JsonNumber6GetNumEPcm();
int PS4_SYSV_ABI _ZNK3sce2np10JsonNumber6GetNumEPi();
int PS4_SYSV_ABI _ZNK3sce2np10JsonNumber6GetNumEPj();
int PS4_SYSV_ABI _ZNK3sce2np10JsonNumber6GetNumEPl();
int PS4_SYSV_ABI _ZNK3sce2np10JsonNumber6GetNumEPm();
int PS4_SYSV_ABI _ZNK3sce2np10JsonNumber9GetNumStrEv();
int PS4_SYSV_ABI _ZNK3sce2np10JsonObject5CloneEP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZNK3sce2np10JsonString5CloneEP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZNK3sce2np10JsonString6GetStrEPcm();
int PS4_SYSV_ABI _ZNK3sce2np10JsonString6GetStrEv();
int PS4_SYSV_ABI _ZNK3sce2np10JsonString9GetLengthEv();
int PS4_SYSV_ABI _ZNK3sce2np12HttpTemplate6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np18HttpConnectionPool6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np3ipc10IpmiClient6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np3ipc17ServiceIpmiClient6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np4Cond6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np4Time18ConvertToPosixTimeEPl();
int PS4_SYSV_ABI _ZNK3sce2np5Mutex6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np6Handle6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np6Thread6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np7RingBuf11GetDataSizeEv();
int PS4_SYSV_ABI _ZNK3sce2np7RingBuf11GetFreeSizeEv();
int PS4_SYSV_ABI _ZNK3sce2np7RingBuf6IsFullEv();
int PS4_SYSV_ABI _ZNK3sce2np7RingBuf7IsEmptyEv();
int PS4_SYSV_ABI _ZNK3sce2np8JsonBool5CloneEP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZNK3sce2np8JsonBool7GetBoolEv();
int PS4_SYSV_ABI _ZNK3sce2np8JsonNull5CloneEP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZNK3sce2np8NpCommId7IsEmptyEv();
int PS4_SYSV_ABI _ZNK3sce2np9EventFlag6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np9HttpTrans6IsInitEv();
int PS4_SYSV_ABI _ZNK3sce2np9JsonArray5CloneEP16SceNpAllocatorEx();
int PS4_SYSV_ABI _ZNK3sce2np9JsonValue12GetItemValueEi();
int PS4_SYSV_ABI _ZNK3sce2np9NpTitleId7IsEmptyEv();
int PS4_SYSV_ABI _ZNK3sce2np9Semaphore6IsInitEv();
int PS4_SYSV_ABI _ZThn16_N3sce2np10MemoryFile5WriteEPNS0_6HandleEPKvmPm();
int PS4_SYSV_ABI _ZThn16_N3sce2np10MemoryFileD0Ev();
int PS4_SYSV_ABI _ZThn16_N3sce2np10MemoryFileD1Ev();
int PS4_SYSV_ABI _ZThn16_N3sce2np9HttpTrans5WriteEPNS0_6HandleEPKvmPm();
int PS4_SYSV_ABI _ZThn16_N3sce2np9HttpTransD0Ev();
int PS4_SYSV_ABI _ZThn16_N3sce2np9HttpTransD1Ev();
int PS4_SYSV_ABI _ZThn16_N3sce2np9LocalFile5WriteEPNS0_6HandleEPKvmPm();
int PS4_SYSV_ABI _ZThn16_N3sce2np9LocalFileD0Ev();
int PS4_SYSV_ABI _ZThn16_N3sce2np9LocalFileD1Ev();
int PS4_SYSV_ABI _ZThn8_N3sce2np10MemoryFile4ReadEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZThn8_N3sce2np10MemoryFileD0Ev();
int PS4_SYSV_ABI _ZThn8_N3sce2np10MemoryFileD1Ev();
int PS4_SYSV_ABI _ZThn8_N3sce2np6Handle10CancelImplEi();
int PS4_SYSV_ABI _ZThn8_N3sce2np6HandleD0Ev();
int PS4_SYSV_ABI _ZThn8_N3sce2np6HandleD1Ev();
int PS4_SYSV_ABI _ZThn8_N3sce2np9HttpTrans4ReadEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZThn8_N3sce2np9HttpTransD0Ev();
int PS4_SYSV_ABI _ZThn8_N3sce2np9HttpTransD1Ev();
int PS4_SYSV_ABI _ZThn8_N3sce2np9LocalFile4ReadEPNS0_6HandleEPvmPm();
int PS4_SYSV_ABI _ZThn8_N3sce2np9LocalFileD0Ev();
int PS4_SYSV_ABI _ZThn8_N3sce2np9LocalFileD1Ev();
int PS4_SYSV_ABI _ZTVN3sce2np10JsonNumberE();
int PS4_SYSV_ABI _ZTVN3sce2np10JsonObjectE();
int PS4_SYSV_ABI _ZTVN3sce2np10JsonStringE();
int PS4_SYSV_ABI _ZTVN3sce2np8JsonBoolE();
int PS4_SYSV_ABI _ZTVN3sce2np8JsonNullE();
int PS4_SYSV_ABI _ZTVN3sce2np8SelectorE();
int PS4_SYSV_ABI _ZTVN3sce2np9JsonArrayE();
int PS4_SYSV_ABI _ZTVN3sce2np9JsonValueE();
int PS4_SYSV_ABI sceNpAllocateKernelMemoryNoAlignment();
int PS4_SYSV_ABI sceNpAllocateKernelMemoryWithAlignment();
int PS4_SYSV_ABI sceNpArchInit();
int PS4_SYSV_ABI sceNpArchTerm();
int PS4_SYSV_ABI sceNpAtomicCas32();
int PS4_SYSV_ABI sceNpAtomicDec32();
int PS4_SYSV_ABI sceNpAtomicInc32();
int PS4_SYSV_ABI sceNpBase64Decoder();
int PS4_SYSV_ABI sceNpBase64Encoder();
int PS4_SYSV_ABI sceNpBase64GetDecodeSize();
int PS4_SYSV_ABI sceNpBase64UrlDecoder();
int PS4_SYSV_ABI sceNpBase64UrlEncoder();
int PS4_SYSV_ABI sceNpBase64UrlGetDecodeSize();
int PS4_SYSV_ABI sceNpCalloutInitCtx();
int PS4_SYSV_ABI sceNpCalloutStartOnCtx();
int PS4_SYSV_ABI sceNpCalloutStartOnCtx64();
int PS4_SYSV_ABI sceNpCalloutStopOnCtx();
int PS4_SYSV_ABI sceNpCalloutTermCtx();
int PS4_SYSV_ABI sceNpCancelEventFlag();
int PS4_SYSV_ABI sceNpClearEventFlag();
int PS4_SYSV_ABI sceNpCloseEventFlag();
int PS4_SYSV_ABI sceNpCloseSema();
int PS4_SYSV_ABI sceNpCondDestroy();
int PS4_SYSV_ABI sceNpCondInit();
int PS4_SYSV_ABI sceNpCondSignal();
int PS4_SYSV_ABI sceNpCondSignalAll();
int PS4_SYSV_ABI sceNpCondSignalTo();
int PS4_SYSV_ABI sceNpCondTimedwait();
int PS4_SYSV_ABI sceNpCondWait();
int PS4_SYSV_ABI sceNpCreateEventFlag();
int PS4_SYSV_ABI sceNpCreateSema();
int PS4_SYSV_ABI sceNpCreateThread();
int PS4_SYSV_ABI sceNpDbgAssignDebugId();
int PS4_SYSV_ABI sceNpDbgDumpBinary();
int PS4_SYSV_ABI sceNpDbgDumpText();
int PS4_SYSV_ABI sceNpDeleteEventFlag();
int PS4_SYSV_ABI sceNpDeleteSema();
int PS4_SYSV_ABI sceNpEventGetCurrentNetworkTick();
int PS4_SYSV_ABI sceNpFreeKernelMemory();
int PS4_SYSV_ABI sceNpGetNavSdkVersion();
int PS4_SYSV_ABI sceNpGetPlatformType();
int PS4_SYSV_ABI sceNpGetProcessId();
int PS4_SYSV_ABI sceNpGetRandom();
int PS4_SYSV_ABI sceNpGetSdkVersion();
int PS4_SYSV_ABI sceNpGetSdkVersionUInt();
int PS4_SYSV_ABI sceNpGetSystemClockUsec();
int PS4_SYSV_ABI sceNpGlobalHeapGetAllocator();
int PS4_SYSV_ABI sceNpGlobalHeapGetAllocatorEx();
int PS4_SYSV_ABI sceNpGlobalHeapGetAllocatorExPtr();
int PS4_SYSV_ABI sceNpGlobalHeapGetAllocatorPtr();
int PS4_SYSV_ABI sceNpHeapDestroy();
int PS4_SYSV_ABI sceNpHeapGetAllocator();
int PS4_SYSV_ABI sceNpHeapGetStat();
int PS4_SYSV_ABI sceNpHeapInit();
int PS4_SYSV_ABI sceNpHeapShowStat();
int PS4_SYSV_ABI sceNpHexToInt();
int PS4_SYSV_ABI sceNpInt32ToStr();
int PS4_SYSV_ABI sceNpInt64ToStr();
int PS4_SYSV_ABI sceNpIntGetPlatformType();
int PS4_SYSV_ABI sceNpIntIsOnlineIdString();
int PS4_SYSV_ABI sceNpIntIsValidOnlineId();
int PS4_SYSV_ABI sceNpIntSetPlatformType();
int PS4_SYSV_ABI sceNpIntToHex();
int PS4_SYSV_ABI sceNpIpc2ClientInit();
int PS4_SYSV_ABI sceNpIpc2ClientTerm();
int PS4_SYSV_ABI sceNpJoinThread();
int PS4_SYSV_ABI sceNpJsonParse();
int PS4_SYSV_ABI sceNpJsonParseBuf();
int PS4_SYSV_ABI sceNpJsonParseBufInit();
int PS4_SYSV_ABI sceNpJsonParseEx();
int PS4_SYSV_ABI sceNpJsonParseExInit();
int PS4_SYSV_ABI sceNpJsonParseInit();
int PS4_SYSV_ABI sceNpLwCondDestroy();
int PS4_SYSV_ABI sceNpLwCondInit();
int PS4_SYSV_ABI sceNpLwCondSignal();
int PS4_SYSV_ABI sceNpLwCondSignalAll();
int PS4_SYSV_ABI sceNpLwCondSignalTo();
int PS4_SYSV_ABI sceNpLwCondWait();
int PS4_SYSV_ABI sceNpLwMutexDestroy();
int PS4_SYSV_ABI sceNpLwMutexInit();
int PS4_SYSV_ABI sceNpLwMutexLock();
int PS4_SYSV_ABI sceNpLwMutexTryLock();
int PS4_SYSV_ABI sceNpLwMutexUnlock();
int PS4_SYSV_ABI sceNpMemoryHeapDestroy();
int PS4_SYSV_ABI sceNpMemoryHeapGetAllocator();
int PS4_SYSV_ABI sceNpMemoryHeapGetAllocatorEx();
int PS4_SYSV_ABI sceNpMemoryHeapInit();
int PS4_SYSV_ABI sceNpMutexDestroy();
int PS4_SYSV_ABI sceNpMutexInit();
int PS4_SYSV_ABI sceNpMutexLock();
int PS4_SYSV_ABI sceNpMutexTryLock();
int PS4_SYSV_ABI sceNpMutexUnlock();
int PS4_SYSV_ABI sceNpOpenEventFlag();
int PS4_SYSV_ABI sceNpOpenSema();
int PS4_SYSV_ABI sceNpPanic();
int PS4_SYSV_ABI sceNpPollEventFlag();
int PS4_SYSV_ABI sceNpPollSema();
int PS4_SYSV_ABI sceNpRtcConvertToPosixTime();
int PS4_SYSV_ABI sceNpRtcFormatRFC3339();
int PS4_SYSV_ABI sceNpRtcParseRFC3339();
int PS4_SYSV_ABI sceNpServerErrorJsonGetErrorCode();
int PS4_SYSV_ABI sceNpServerErrorJsonMultiGetErrorCode();
int PS4_SYSV_ABI sceNpServerErrorJsonParse();
int PS4_SYSV_ABI sceNpServerErrorJsonParseInit();
int PS4_SYSV_ABI sceNpServerErrorJsonParseMultiInit();
int PS4_SYSV_ABI sceNpSetEventFlag();
int PS4_SYSV_ABI sceNpSetPlatformType();
int PS4_SYSV_ABI sceNpSignalSema();
int PS4_SYSV_ABI sceNpStrBuildHex();
int PS4_SYSV_ABI sceNpStrcpyToBuf();
int PS4_SYSV_ABI sceNpStrncpyToBuf();
int PS4_SYSV_ABI sceNpStrnParseHex();
int PS4_SYSV_ABI sceNpStrParseHex();
int PS4_SYSV_ABI sceNpStrToInt32();
int PS4_SYSV_ABI sceNpStrToInt64();
int PS4_SYSV_ABI sceNpStrToUInt32();
int PS4_SYSV_ABI sceNpStrToUInt64();
int PS4_SYSV_ABI sceNpThreadGetId();
int PS4_SYSV_ABI sceNpUInt32ToStr();
int PS4_SYSV_ABI sceNpUInt64ToStr();
int PS4_SYSV_ABI sceNpUserGetUserIdList();
int PS4_SYSV_ABI sceNpUtilBuildTitleId();
int PS4_SYSV_ABI sceNpUtilCanonicalizeNpIdForPs4();
int PS4_SYSV_ABI sceNpUtilCanonicalizeNpIdForPsp2();
int PS4_SYSV_ABI sceNpUtilCmpAccountId();
int PS4_SYSV_ABI sceNpUtilGetDateSetAuto();
int PS4_SYSV_ABI sceNpUtilGetDbgCommerce();
int PS4_SYSV_ABI sceNpUtilGetEnv();
int PS4_SYSV_ABI sceNpUtilGetFakeDisplayNameMode();
int PS4_SYSV_ABI sceNpUtilGetFakeRateLimit();
int PS4_SYSV_ABI sceNpUtilGetIgnoreNpTitleId();
int PS4_SYSV_ABI sceNpUtilGetNpDebug();
int PS4_SYSV_ABI sceNpUtilGetNpLanguageCode();
int PS4_SYSV_ABI sceNpUtilGetNpLanguageCode2();
int PS4_SYSV_ABI sceNpUtilGetNpLanguageCode2Str();
int PS4_SYSV_ABI sceNpUtilGetNpLanguageCodeStr();
int PS4_SYSV_ABI sceNpUtilGetNpTestPatch();
int PS4_SYSV_ABI sceNpUtilGetNthChar();
int PS4_SYSV_ABI sceNpUtilGetShareTitleCheck();
int PS4_SYSV_ABI sceNpUtilGetSystemLanguage();
int PS4_SYSV_ABI sceNpUtilGetTrcNotify();
int PS4_SYSV_ABI sceNpUtilGetWebApi2FakeRateLimit();
int PS4_SYSV_ABI sceNpUtilGetWebApi2FakeRateLimitTarget();
int PS4_SYSV_ABI sceNpUtilGetWebTraceSetting();
int PS4_SYSV_ABI sceNpUtilHttpUrlEncode();
int PS4_SYSV_ABI sceNpUtilJidToNpId();
int PS4_SYSV_ABI sceNpUtilJsonEscape();
int PS4_SYSV_ABI sceNpUtilJsonGetOneChar();
int PS4_SYSV_ABI sceNpUtilJsonUnescape();
int PS4_SYSV_ABI sceNpUtilNpIdToJid();
int PS4_SYSV_ABI sceNpUtilNumChars();
int PS4_SYSV_ABI sceNpUtilParseJid();
int PS4_SYSV_ABI sceNpUtilParseTitleId();
int PS4_SYSV_ABI sceNpUtilSerializeJid();
int PS4_SYSV_ABI sceNpUtilXmlEscape();
int PS4_SYSV_ABI sceNpUtilXmlGetOneChar();
int PS4_SYSV_ABI sceNpUtilXmlUnescape();
int PS4_SYSV_ABI sceNpWaitEventFlag();
int PS4_SYSV_ABI sceNpWaitSema();
int PS4_SYSV_ABI sceNpXmlParse();
int PS4_SYSV_ABI sceNpXmlParseInit();
int PS4_SYSV_ABI Func_00FD578C2DD966DF();
int PS4_SYSV_ABI Func_0131A2EA80689F4C();
int PS4_SYSV_ABI Func_01443C54863BDD20();
int PS4_SYSV_ABI Func_01BC55BDC5C0ADAD();
int PS4_SYSV_ABI Func_01D1ECF5750F40E8();
int PS4_SYSV_ABI Func_020A479A74F5FBAC();
int PS4_SYSV_ABI Func_024AF5E1D9472AB5();
int PS4_SYSV_ABI Func_027C5D488713A6B3();
int PS4_SYSV_ABI Func_02FE9D94C6858355();
int PS4_SYSV_ABI Func_041F34F1C70D15C1();
int PS4_SYSV_ABI Func_0530B1D276114248();
int PS4_SYSV_ABI Func_065DAA14E9C73AD9();
int PS4_SYSV_ABI Func_06AFF4E5D042BC3E();
int PS4_SYSV_ABI Func_06EE369299F73997();
int PS4_SYSV_ABI Func_07C92D9F8D76B617();
int PS4_SYSV_ABI Func_07E9117498F1E4BF();
int PS4_SYSV_ABI Func_08F3E0AF3664F275();
int PS4_SYSV_ABI Func_0A9937C01EF21375();
int PS4_SYSV_ABI Func_0ACBE6ACCBA3876D();
int PS4_SYSV_ABI Func_0AE07D3354510CE6();
int PS4_SYSV_ABI Func_0AEC3C342AE67B7C();
int PS4_SYSV_ABI Func_0B318420C11E7C23();
int PS4_SYSV_ABI Func_0BB6C37B03F35D89();
int PS4_SYSV_ABI Func_0BBE8A9ACDD90FDF();
int PS4_SYSV_ABI Func_0C7B62905E224E9C();
int PS4_SYSV_ABI Func_0D35913117241AF9();
int PS4_SYSV_ABI Func_0D5EE95CEED879A7();
int PS4_SYSV_ABI Func_0D6FB24B27AB1DA2();
int PS4_SYSV_ABI Func_0DE8032D534AC41C();
int PS4_SYSV_ABI Func_0DF4CCA9DCA9E742();
int PS4_SYSV_ABI Func_0E7449B1D3D98C01();
int PS4_SYSV_ABI Func_0E77094B7750CB37();
int PS4_SYSV_ABI Func_0ECAB397B6D50603();
int PS4_SYSV_ABI Func_0F1DE1D1EADA2948();
int PS4_SYSV_ABI Func_0F8AFEFA1D26BF1A();
int PS4_SYSV_ABI Func_11881710562A6BAD();
int PS4_SYSV_ABI Func_11AFD88BBD0C70DB();
int PS4_SYSV_ABI Func_11E704A30A4B8877();
int PS4_SYSV_ABI Func_125014842452F94B();
int PS4_SYSV_ABI Func_126F0071E11CAC46();
int PS4_SYSV_ABI Func_12926DCF35994B01();
int PS4_SYSV_ABI Func_12CC7ABFBF31618F();
int PS4_SYSV_ABI Func_13C4E51F44592AA2();
int PS4_SYSV_ABI Func_15330E7C56338254();
int PS4_SYSV_ABI Func_1566B358CABF2612();
int PS4_SYSV_ABI Func_1625818F268F45EF();
int PS4_SYSV_ABI Func_16D32B40D28A9AC2();
int PS4_SYSV_ABI Func_183F4483BDBD25CD();
int PS4_SYSV_ABI Func_1887E9E95AF62F3D();
int PS4_SYSV_ABI Func_18A3CE95FD893D3A();
int PS4_SYSV_ABI Func_18B3665E4854E7E9();
int PS4_SYSV_ABI Func_1923B003948AF47E();
int PS4_SYSV_ABI Func_19B533DA4C59A532();
int PS4_SYSV_ABI Func_1BB399772DB68E08();
int PS4_SYSV_ABI Func_1C0AC612D3A2971B();
int PS4_SYSV_ABI Func_1C5599B779990A43();
int PS4_SYSV_ABI Func_1CCBB296B04317BE();
int PS4_SYSV_ABI Func_1CD045542FB93002();
int PS4_SYSV_ABI Func_1DECECA673AB77B7();
int PS4_SYSV_ABI Func_1E03E024E26C1A7F();
int PS4_SYSV_ABI Func_1F101732BB0D7E21();
int PS4_SYSV_ABI Func_1F4D153EC3DD47BB();
int PS4_SYSV_ABI Func_1F7C47F63FAF0CBE();
int PS4_SYSV_ABI Func_1FBE2EE68C0F31B6();
int PS4_SYSV_ABI Func_2038C1628914B9C9();
int PS4_SYSV_ABI Func_203FCB56FDB86A74();
int PS4_SYSV_ABI Func_20569C107C6CB08C();
int PS4_SYSV_ABI Func_20AB2D734EDE55F0();
int PS4_SYSV_ABI Func_22B1281180FB0A5E();
int PS4_SYSV_ABI Func_22F1AADA66A449AE();
int PS4_SYSV_ABI Func_238B215EFFDF3D30();
int PS4_SYSV_ABI Func_24E8EC51D149FA15();
int PS4_SYSV_ABI Func_25728E78A3962C02();
int PS4_SYSV_ABI Func_25E649A1C6891C05();
int PS4_SYSV_ABI Func_264B8A38B577705D();
int PS4_SYSV_ABI Func_266ED08DC1C82A0E();
int PS4_SYSV_ABI Func_27BB4DE62AB58BAD();
int PS4_SYSV_ABI Func_283AA96A196EA2EA();
int PS4_SYSV_ABI Func_285315A390A85A94();
int PS4_SYSV_ABI Func_29049DBB1EF3194E();
int PS4_SYSV_ABI Func_29F7BA9C3732CB47();
int PS4_SYSV_ABI Func_2A732DF331ACCB37();
int PS4_SYSV_ABI Func_2AA01660EC75B6FB();
int PS4_SYSV_ABI Func_2B37CBCE941C1681();
int PS4_SYSV_ABI Func_2CAA3B64D0544E55();
int PS4_SYSV_ABI Func_2CCD79617EC10A75();
int PS4_SYSV_ABI Func_2CD8B69716AC0667();
int PS4_SYSV_ABI Func_2D74F7C0FF9B5E9C();
int PS4_SYSV_ABI Func_2DCA5A8080544E95();
int PS4_SYSV_ABI Func_2E69F2743CE7CE57();
int PS4_SYSV_ABI Func_2EAF1F3BAFF0527D();
int PS4_SYSV_ABI Func_31493E55BB4E8F66();
int PS4_SYSV_ABI Func_317EDCAD00FB5F5E();
int PS4_SYSV_ABI Func_31E01CFA8A18CDA2();
int PS4_SYSV_ABI Func_32AFD782A061B526();
int PS4_SYSV_ABI Func_32B5CDEB093B8189();
int PS4_SYSV_ABI Func_34155152513C93AE();
int PS4_SYSV_ABI Func_34E4EFFF8EF6C9FE();
int PS4_SYSV_ABI Func_3572FA0D5C54563B();
int PS4_SYSV_ABI Func_367C479B264E0DB9();
int PS4_SYSV_ABI Func_36884FBC964B29CC();
int PS4_SYSV_ABI Func_3860081BB7559949();
int PS4_SYSV_ABI Func_39314F7E674AB132();
int PS4_SYSV_ABI Func_3A02E780FCC556A5();
int PS4_SYSV_ABI Func_3A17B885BA4849B6();
int PS4_SYSV_ABI Func_3A38EACAEA5E23A4();
int PS4_SYSV_ABI Func_3B34A5E07F0DBC1F();
int PS4_SYSV_ABI Func_3B4E8FFC00FC7EA4();
int PS4_SYSV_ABI Func_3BAB18FDA235107A();
int PS4_SYSV_ABI Func_3BDF9996A0A33F11();
int PS4_SYSV_ABI Func_3C1952F1A45CC37A();
int PS4_SYSV_ABI Func_3CA37906CDB05F3B();
int PS4_SYSV_ABI Func_3CDB2908ACEE3A6F();
int PS4_SYSV_ABI Func_3D3ED165F2BDCD33();
int PS4_SYSV_ABI Func_3DA4D7D1575FCDCE();
int PS4_SYSV_ABI Func_3DDFB612CD0BC769();
int PS4_SYSV_ABI Func_3E0415E167DEADC7();
int PS4_SYSV_ABI Func_3E7E9F0F1581C1E6();
int PS4_SYSV_ABI Func_3ED389DB8280ED65();
int PS4_SYSV_ABI Func_3F0C7F6C0C35487D();
int PS4_SYSV_ABI Func_3FDA7200389EF0D2();
int PS4_SYSV_ABI Func_3FF3C258BA516E58();
int PS4_SYSV_ABI Func_4029453F628A3C5D();
int PS4_SYSV_ABI Func_405826DDB4AE538E();
int PS4_SYSV_ABI Func_405A926759F25865();
int PS4_SYSV_ABI Func_406608FDEE7AE88A();
int PS4_SYSV_ABI Func_40DDA5558C17DDCF();
int PS4_SYSV_ABI Func_419D12E52FF60664();
int PS4_SYSV_ABI Func_4296E539474BE77F();
int PS4_SYSV_ABI Func_42F41FC563CC3654();
int PS4_SYSV_ABI Func_43CCC86F4C93026A();
int PS4_SYSV_ABI Func_4409F60BDABC65E1();
int PS4_SYSV_ABI Func_4563C70AEC675382();
int PS4_SYSV_ABI Func_45E66370219BD05E();
int PS4_SYSV_ABI Func_466A54F072785696();
int PS4_SYSV_ABI Func_46CD2536976F209A();
int PS4_SYSV_ABI Func_4863717BD2FDD157();
int PS4_SYSV_ABI Func_4902EBD19A263149();
int PS4_SYSV_ABI Func_4904F7FE8D83F40C();
int PS4_SYSV_ABI Func_4A5E13F784ABFCE7();
int PS4_SYSV_ABI Func_4B65EEB135C12781();
int PS4_SYSV_ABI Func_4C19D49978DA85E2();
int PS4_SYSV_ABI Func_4DE5D620FF66F136();
int PS4_SYSV_ABI Func_4E170C12B57A8F9E();
int PS4_SYSV_ABI Func_4E2F3FA405C3260C();
int PS4_SYSV_ABI Func_4EA9350577513B4D();
int PS4_SYSV_ABI Func_4F78EB6FC4B5F21F();
int PS4_SYSV_ABI Func_50348BE4331117B7();
int PS4_SYSV_ABI Func_508C7E8CDD281CAA();
int PS4_SYSV_ABI Func_521C1D2C028F5A7E();
int PS4_SYSV_ABI Func_522FF24A35E67291();
int PS4_SYSV_ABI Func_5470FE90C25CDD4C();
int PS4_SYSV_ABI Func_557F260F9A4ACD18();
int PS4_SYSV_ABI Func_5586F97209F391EB();
int PS4_SYSV_ABI Func_55B2C9B7ADA95C3C();
int PS4_SYSV_ABI Func_55B488A3A540B936();
int PS4_SYSV_ABI Func_5642DFE82AF43143();
int PS4_SYSV_ABI Func_574E046F294AE187();
int PS4_SYSV_ABI Func_578926EBF8AA6CBF();
int PS4_SYSV_ABI Func_585DA5FC650896BC();
int PS4_SYSV_ABI Func_58D6EB27349EC276();
int PS4_SYSV_ABI Func_5906B7317949872D();
int PS4_SYSV_ABI Func_5910B5614335BE70();
int PS4_SYSV_ABI Func_593D7DA8911F08C9();
int PS4_SYSV_ABI Func_59757FE6A93B0D53();
int PS4_SYSV_ABI Func_598E60F862B1141E();
int PS4_SYSV_ABI Func_5A45351666680DAF();
int PS4_SYSV_ABI Func_5AABE9EA702E6A7F();
int PS4_SYSV_ABI Func_5AEA4AE472355B80();
int PS4_SYSV_ABI Func_5B20E53CDE598741();
int PS4_SYSV_ABI Func_5B480B59FAE947E0();
int PS4_SYSV_ABI Func_5B5EEC23690AB9BD();
int PS4_SYSV_ABI Func_5C0AC5B0AF3EDAE0();
int PS4_SYSV_ABI Func_5D2E999BEA0762D4();
int PS4_SYSV_ABI Func_5D55BBFD45110E16();
int PS4_SYSV_ABI Func_5DEE15403D2BB5FD();
int PS4_SYSV_ABI Func_6020C708CA74B130();
int PS4_SYSV_ABI Func_606E1415503C34D2();
int PS4_SYSV_ABI Func_612140E8EE9A693E();
int PS4_SYSV_ABI Func_61F13F551DAF61DF();
int PS4_SYSV_ABI Func_6206D39131752328();
int PS4_SYSV_ABI Func_621D4543EF0344DE();
int PS4_SYSV_ABI Func_6259A9A8E56D0273();
int PS4_SYSV_ABI Func_625F9C7016346F4E();
int PS4_SYSV_ABI Func_62EF8DF746CD8C4A();
int PS4_SYSV_ABI Func_636D2A99FD1E6B2B();
int PS4_SYSV_ABI Func_68013EDF66FE7425();
int PS4_SYSV_ABI Func_6971F7067DD639D1();
int PS4_SYSV_ABI Func_69896ADB3AB410B2();
int PS4_SYSV_ABI Func_6A1389AA6E561387();
int PS4_SYSV_ABI Func_6A5560D89F12B2E7();
int PS4_SYSV_ABI Func_6ABF99CF854ABCF1();
int PS4_SYSV_ABI Func_6B4FDDC6500D8DCB();
int PS4_SYSV_ABI Func_6CA11D5B49D1928A();
int PS4_SYSV_ABI Func_6D6C0FB61E6D0715();
int PS4_SYSV_ABI Func_6D750745FE1348F5();
int PS4_SYSV_ABI Func_6E1AF3F9D09914BE();
int PS4_SYSV_ABI Func_6E53ED4C08B2A521();
int PS4_SYSV_ABI Func_6EF43ACA1ED6B968();
int PS4_SYSV_ABI Func_6F6FA09F3E1B6A60();
int PS4_SYSV_ABI Func_7035C340C7195901();
int PS4_SYSV_ABI Func_7038E21CB5CF641B();
int PS4_SYSV_ABI Func_706345DCDA5BA44D();
int PS4_SYSV_ABI Func_7120714EBF10BF1F();
int PS4_SYSV_ABI Func_713D28A91BC803DD();
int PS4_SYSV_ABI Func_7153BD76A53AA012();
int PS4_SYSV_ABI Func_715C625CC7041B6B();
int PS4_SYSV_ABI Func_71E467BDB18711D0();
int PS4_SYSV_ABI Func_720D17965C1F4E3F();
int PS4_SYSV_ABI Func_734380C9BCF65B9A();
int PS4_SYSV_ABI Func_73F4C08CCD4BBCCF();
int PS4_SYSV_ABI Func_74403101B7B29D46();
int PS4_SYSV_ABI Func_7525B081ACD66FF4();
int PS4_SYSV_ABI Func_75BF4477C13A05CA();
int PS4_SYSV_ABI Func_7609793F5987C6F7();
int PS4_SYSV_ABI Func_7616ED01B04769AA();
int PS4_SYSV_ABI Func_764F873D91A124D8();
int PS4_SYSV_ABI Func_7706F1E123059565();
int PS4_SYSV_ABI Func_77F2D07EB6D806E6();
int PS4_SYSV_ABI Func_79C3704CDCD59E57();
int PS4_SYSV_ABI Func_79DA0BBA21351545();
int PS4_SYSV_ABI Func_79FA2447B5F3F0C4();
int PS4_SYSV_ABI Func_7A4D6F65FF6195A5();
int PS4_SYSV_ABI Func_7B3195CD114DECE7();
int PS4_SYSV_ABI Func_7B3238F2301AD36D();
int PS4_SYSV_ABI Func_7C77FC70750A3266();
int PS4_SYSV_ABI Func_7D23A9DC459D6D18();
int PS4_SYSV_ABI Func_7D5988C748D0A05F();
int PS4_SYSV_ABI Func_7D9597147A99F4F4();
int PS4_SYSV_ABI Func_7E2953F407DD8346();
int PS4_SYSV_ABI Func_7EE34E5099709B32();
int PS4_SYSV_ABI Func_80470E5511D5CA00();
int PS4_SYSV_ABI Func_807179701C08F069();
int PS4_SYSV_ABI Func_8096E81FFAF24E46();
int PS4_SYSV_ABI Func_80B764F4F1B87042();
int PS4_SYSV_ABI Func_80BF691438AD008B();
int PS4_SYSV_ABI Func_80CF6CFC96012442();
int PS4_SYSV_ABI Func_80EA772F8C0519FD();
int PS4_SYSV_ABI Func_81D0AFD0084D327A();
int PS4_SYSV_ABI Func_821EB8A72176FD67();
int PS4_SYSV_ABI Func_82D2FAB54127273F();
int PS4_SYSV_ABI Func_836AE669C42A59E9();
int PS4_SYSV_ABI Func_8559A25BFEC3518C();
int PS4_SYSV_ABI Func_85C1F66C767A49D2();
int PS4_SYSV_ABI Func_8689ED1383F87BA7();
int PS4_SYSV_ABI Func_8796CD9E5355D3A6();
int PS4_SYSV_ABI Func_87D37EB6DDC19D99();
int PS4_SYSV_ABI Func_880AA48F70F84FDD();
int PS4_SYSV_ABI Func_897B07562093665B();
int PS4_SYSV_ABI Func_8ACAF55F16368087();
int PS4_SYSV_ABI Func_8AE8A5589B30D4E0();
int PS4_SYSV_ABI Func_8AE997909831B331();
int PS4_SYSV_ABI Func_8B2D640BE0D0FB99();
int PS4_SYSV_ABI Func_8B3D9AB4668DAECB();
int PS4_SYSV_ABI Func_8B5EFAAAACE0B46C();
int PS4_SYSV_ABI Func_8C27943F40A988DB();
int PS4_SYSV_ABI Func_8C54096C75F5F2D0();
int PS4_SYSV_ABI Func_8D7663A0A5168814();
int PS4_SYSV_ABI Func_8E618F509994FAD7();
int PS4_SYSV_ABI Func_8F19E6CC064E2B98();
int PS4_SYSV_ABI Func_8F6A8AEAEE922FF5();
int PS4_SYSV_ABI Func_9010E1AD8EBBFBCA();
int PS4_SYSV_ABI Func_90A955A0E7001AE9();
int PS4_SYSV_ABI Func_90F9D6067FEECC05();
int PS4_SYSV_ABI Func_9348F3D19546A1DA();
int PS4_SYSV_ABI Func_93D3C011DB19388A();
int PS4_SYSV_ABI Func_956E7A4FD9F89103();
int PS4_SYSV_ABI Func_95F699E042C3E40F();
int PS4_SYSV_ABI Func_96877B39AA0E8735();
int PS4_SYSV_ABI Func_96CE07C49ED234EA();
int PS4_SYSV_ABI Func_976BB178235B5681();
int PS4_SYSV_ABI Func_978C0B25E588C4D6();
int PS4_SYSV_ABI Func_98BA2612BEF238D6();
int PS4_SYSV_ABI Func_995BDD4931AF9137();
int PS4_SYSV_ABI Func_9966E39A926B7250();
int PS4_SYSV_ABI Func_99C2306F18963464();
int PS4_SYSV_ABI Func_99C92C613B776BA7();
int PS4_SYSV_ABI Func_9A4E4B938CC8AD39();
int PS4_SYSV_ABI Func_9B23F7B4B7F72081();
int PS4_SYSV_ABI Func_9C0EAEEAE705A8DB();
int PS4_SYSV_ABI Func_9D47AC59545DE9E8();
int PS4_SYSV_ABI Func_A13052D8B1B2ACFA();
int PS4_SYSV_ABI Func_A1AA43E3A78F6F62();
int PS4_SYSV_ABI Func_A1E48CDF54649DC9();
int PS4_SYSV_ABI Func_A2E7DEE5B0AF5D14();
int PS4_SYSV_ABI Func_A2F5C7FD9FF113F5();
int PS4_SYSV_ABI Func_A36296E2269D46BC();
int PS4_SYSV_ABI Func_A3EE2A7B9F0D88AF();
int PS4_SYSV_ABI Func_A4471F9F7E0BFA82();
int PS4_SYSV_ABI Func_A449BBA521EA34E1();
int PS4_SYSV_ABI Func_A48E666C334E726C();
int PS4_SYSV_ABI Func_A49B7449B4DDE69C();
int PS4_SYSV_ABI Func_A5748451125C9EA4();
int PS4_SYSV_ABI Func_A690A28D648CC176();
int PS4_SYSV_ABI Func_A6A86DE1B1CBB1D9();
int PS4_SYSV_ABI Func_A8F2BB7B815740A1();
int PS4_SYSV_ABI Func_A93F64C06A6F7397();
int PS4_SYSV_ABI Func_AB35925FC97D6AA3();
int PS4_SYSV_ABI Func_AC014AA2C991FA29();
int PS4_SYSV_ABI Func_AC06E10901404AEB();
int PS4_SYSV_ABI Func_AC75C68813523505();
int PS4_SYSV_ABI Func_AD441BC497082C3E();
int PS4_SYSV_ABI Func_AD4F25F021D354C3();
int PS4_SYSV_ABI Func_ADFA04A85541A4FE();
int PS4_SYSV_ABI Func_AE9610A6B5217A23();
int PS4_SYSV_ABI Func_AF201923826F0A58();
int PS4_SYSV_ABI Func_AFC021B4389CA3FA();
int PS4_SYSV_ABI Func_B015E999A3373D8F();
int PS4_SYSV_ABI Func_B0384B86107FC652();
int PS4_SYSV_ABI Func_B0C630653B316563();
int PS4_SYSV_ABI Func_B100DCCD88D5C73D();
int PS4_SYSV_ABI Func_B11A3FEA5E4D9EA4();
int PS4_SYSV_ABI Func_B2E7F8DC199C0B93();
int PS4_SYSV_ABI Func_B3AB61A296F6DDC8();
int PS4_SYSV_ABI Func_B3F32F6AE619EC82();
int PS4_SYSV_ABI Func_B4227AB213BF8CF5();
int PS4_SYSV_ABI Func_B4652BF42B604360();
int PS4_SYSV_ABI Func_B536C1F13BFE97CB();
int PS4_SYSV_ABI Func_B645CC264184BC89();
int PS4_SYSV_ABI Func_B67E17B1582C6FBD();
int PS4_SYSV_ABI Func_B6D047C5D7695A4D();
int PS4_SYSV_ABI Func_B75ED8E1EA62EFC7();
int PS4_SYSV_ABI Func_B7A9A944DBD7E100();
int PS4_SYSV_ABI Func_B7C4E75BE94F31F3();
int PS4_SYSV_ABI Func_B888B1F92C464121();
int PS4_SYSV_ABI Func_B8DEC22564AA057B();
int PS4_SYSV_ABI Func_B9BADD1CBBBAE4F8();
int PS4_SYSV_ABI Func_BAA9F7169C85E59F();
int PS4_SYSV_ABI Func_BAEE5C38908D62DB();
int PS4_SYSV_ABI Func_BCC855EB25183F84();
int PS4_SYSV_ABI Func_BD01F637029C7364();
int PS4_SYSV_ABI Func_BDD29F5AC7077E53();
int PS4_SYSV_ABI Func_BED83DD33ECAD50D();
int PS4_SYSV_ABI Func_BEE7D5D098ABF728();
int PS4_SYSV_ABI Func_C0DB15CCF59AE62C();
int PS4_SYSV_ABI Func_C1C229FEE0FD60FA();
int PS4_SYSV_ABI Func_C228B9AD68298E98();
int PS4_SYSV_ABI Func_C298525CEF6FB283();
int PS4_SYSV_ABI Func_C350F09351F6D6B5();
int PS4_SYSV_ABI Func_C3742E80FA580319();
int PS4_SYSV_ABI Func_C3C9853D5D4D45D4();
int PS4_SYSV_ABI Func_C3F5DAD4FB9FC340();
int PS4_SYSV_ABI Func_C45FB0E4CCE9AED6();
int PS4_SYSV_ABI Func_C4979CB948B7E3C7();
int PS4_SYSV_ABI Func_C49B25BA16CF0B8C();
int PS4_SYSV_ABI Func_C551345D9631201E();
int PS4_SYSV_ABI Func_C57A294421368298();
int PS4_SYSV_ABI Func_C5DC91CAD721D628();
int PS4_SYSV_ABI Func_C6DECEE589135357();
int PS4_SYSV_ABI Func_C81F8B20D67AC78D();
int PS4_SYSV_ABI Func_C820FA56FAC87BEA();
int PS4_SYSV_ABI Func_C878EA9114C5E490();
int PS4_SYSV_ABI Func_C8A813EBFF477509();
int PS4_SYSV_ABI Func_C966A663D5A35482();
int PS4_SYSV_ABI Func_C97C4C67FD3674D3();
int PS4_SYSV_ABI Func_C990550F15848B07();
int PS4_SYSV_ABI Func_CA59737A8EC1BBBE();
int PS4_SYSV_ABI Func_CAC5FDE8F80D7B65();
int PS4_SYSV_ABI Func_CB135B30D0639B83();
int PS4_SYSV_ABI Func_CB8A1AAA61F64C3A();
int PS4_SYSV_ABI Func_CB9E674672580757();
int PS4_SYSV_ABI Func_CC2B9D25EAEAAB1D();
int PS4_SYSV_ABI Func_CD1B252BBEDF5B53();
int PS4_SYSV_ABI Func_CF003BE90CBE1A27();
int PS4_SYSV_ABI Func_CF008E34884AC1E2();
int PS4_SYSV_ABI Func_D0B8F4B3A3687AB2();
int PS4_SYSV_ABI Func_D0EE19B8E91F60F5();
int PS4_SYSV_ABI Func_D12B9294BD0E0F56();
int PS4_SYSV_ABI Func_D1CC8626D8FA328B();
int PS4_SYSV_ABI Func_D2FA2BB9EB8B63AC();
int PS4_SYSV_ABI Func_D32197880CF93CEB();
int PS4_SYSV_ABI Func_D326F5C26CC81B8E();
int PS4_SYSV_ABI Func_D4FA06B95A321B7A();
int PS4_SYSV_ABI Func_D52A37A901E04B21();
int PS4_SYSV_ABI Func_D5504DFC399AB400();
int PS4_SYSV_ABI Func_D56105CB27F8F5DC();
int PS4_SYSV_ABI Func_D568AB19235ECB19();
int PS4_SYSV_ABI Func_D6DF7BF6639FE611();
int PS4_SYSV_ABI Func_D8608A903119D746();
int PS4_SYSV_ABI Func_D9E8FC707D59914D();
int PS4_SYSV_ABI Func_D9F079E62DEE5B29();
int PS4_SYSV_ABI Func_DA17CE4F29748536();
int PS4_SYSV_ABI Func_DA40B9EFD7F61185();
int PS4_SYSV_ABI Func_DA6B274FEBC2666A();
int PS4_SYSV_ABI Func_DAD01535C87A51FC();
int PS4_SYSV_ABI Func_DB4511D448510EC4();
int PS4_SYSV_ABI Func_DB8EF1FFFC66269C();
int PS4_SYSV_ABI Func_DBB508FA1B9DA8F7();
int PS4_SYSV_ABI Func_DC59C9B870B729A2();
int PS4_SYSV_ABI Func_DC669ED6CBF6751C();
int PS4_SYSV_ABI Func_DCB8A2849A41C991();
int PS4_SYSV_ABI Func_DD8F9916D7F03AF7();
int PS4_SYSV_ABI Func_DDC33F2F4E480C2A();
int PS4_SYSV_ABI Func_DE0B420BDE8B22D7();
int PS4_SYSV_ABI Func_E0C0BC29898FE370();
int PS4_SYSV_ABI Func_E0CD893E46FB55BA();
int PS4_SYSV_ABI Func_E25530164B7F659F();
int PS4_SYSV_ABI Func_E3682F43FDF76C58();
int PS4_SYSV_ABI Func_E38177E1C78A80FA();
int PS4_SYSV_ABI Func_E3CA74CFF965DF0A();
int PS4_SYSV_ABI Func_E45BB191B49B2ED9();
int PS4_SYSV_ABI Func_E465B9D6B60E6D7D();
int PS4_SYSV_ABI Func_E4D82876C296C38A();
int PS4_SYSV_ABI Func_E4DDB5350FA5B538();
int PS4_SYSV_ABI Func_E54BFF6FB72BC7BE();
int PS4_SYSV_ABI Func_E592A93203020BBB();
int PS4_SYSV_ABI Func_E5A44AF6D7D48AFD();
int PS4_SYSV_ABI Func_E639A97CF9FF1430();
int PS4_SYSV_ABI Func_E6AC0179E48A8927();
int PS4_SYSV_ABI Func_E751596682775D83();
int PS4_SYSV_ABI Func_E788B1E52EF82702();
int PS4_SYSV_ABI Func_E94F17613F5C9D31();
int PS4_SYSV_ABI Func_E9590113128D55E0();
int PS4_SYSV_ABI Func_E9E0B0DD12560B16();
int PS4_SYSV_ABI Func_EAF5C8ECE64C7B05();
int PS4_SYSV_ABI Func_EB98BF5C42D4A7EB();
int PS4_SYSV_ABI Func_EBABC4AAC43A468C();
int PS4_SYSV_ABI Func_EBF00085F082CC8B();
int PS4_SYSV_ABI Func_ECB659EE058D06AF();
int PS4_SYSV_ABI Func_ECF096AB751487AE();
int PS4_SYSV_ABI Func_EE5A271701DB33C0();
int PS4_SYSV_ABI Func_EF64CB6A1625248E();
int PS4_SYSV_ABI Func_EF6C8A357C7ED863();
int PS4_SYSV_ABI Func_F00FE94F7E699994();
int PS4_SYSV_ABI Func_F1A51DBA30329038();
int PS4_SYSV_ABI Func_F216E766A90FDC12();
int PS4_SYSV_ABI Func_F2A10584ABE5D82C();
int PS4_SYSV_ABI Func_F2D99D395E5421A3();
int PS4_SYSV_ABI Func_F38001E528BA1371();
int PS4_SYSV_ABI Func_F39EC9C8FA7687B3();
int PS4_SYSV_ABI Func_F3AFFFDCD632775C();
int PS4_SYSV_ABI Func_F3B8DFF33748BFD3();
int PS4_SYSV_ABI Func_F5E47F9550F7A147();
int PS4_SYSV_ABI Func_F6E93714D1A939CF();
int PS4_SYSV_ABI Func_F6FD19AD48E4EF09();
int PS4_SYSV_ABI Func_F744EBFC620F7CBF();
int PS4_SYSV_ABI Func_F76E4525ACBACC7F();
int PS4_SYSV_ABI Func_F7957A48882F42CB();
int PS4_SYSV_ABI Func_F7A80B07809BA838();
int PS4_SYSV_ABI Func_F8571C6CC5B6B59D();
int PS4_SYSV_ABI Func_F9787CFA873836FB();
int PS4_SYSV_ABI Func_FA789F6D34D383F8();
int PS4_SYSV_ABI Func_FABA574083AC1E6C();
int PS4_SYSV_ABI Func_FC04FDBBAE368FB7();
int PS4_SYSV_ABI Func_FD2DAFBF2E40EEE7();
int PS4_SYSV_ABI Func_FD55EE6D35F950AD();
int PS4_SYSV_ABI Func_FE55EE32098D0D58();
int PS4_SYSV_ABI Func_FE79841022E1DA1C();
int PS4_SYSV_ABI Func_FFF4A3E279FB44A7();

void RegisterLib(Core::Loader::SymbolsResolver* sym);
} // namespace Libraries::NpCommon